@@ -25,9 +25,9 @@ class GenericControllerClass:
         
     def exploreCluster(self, connect_db_output, source, unique_source_data, i,source_by_create_date, data_cluster_representative, flag_data, generic):
         try:
-            print("exploreCluster . . .")
+            # print("exploreCluster . . .")
             if(len(data_cluster_representative) > 0): # เจอกลุ่ม
-                print("Find cluster ...")
+                # print("Find cluster ...")
                 if(str(data_cluster_representative.iloc[0]["representative_id"]) not in flag_data["flag_representative_id_list"]):
                     flag_data["flag_representative_id_list"].append(str(data_cluster_representative.iloc[0]["representative_id"]))
                     flag_data["flag_representative_list_df"].append(data_cluster_representative)
@@ -75,7 +75,7 @@ class GenericControllerClass:
                     source_for_update = source_by_create_date[source_by_create_date[self.data_app_config["member"]["field_pk"]].isin(source_duplicate[self.data_app_config["member"]["field_pk"]])]  # for update
                     return [True, source_for_insert, source_for_update, flag_data, data_member] # for insert, update
             
-            print("New cluster ...")
+            # print("New cluster ...")
 
             flag_data["flag_representative_update"] = ""
             if(self.data_app_config["continuity"]["required"]):
@@ -183,7 +183,7 @@ class GenericControllerClass:
             where """ + sql_where_pk +""" and start_date <= '""" + data_source[pk_report_start_date] + """'
             and end_date >= '""" + data_source[pk_report_start_date] + """' """
 
-            print("getClusterRepresentative . . .")
+            # print("getClusterRepresentative . . .")
             return connect_db_output.queryRead(sql)
         except Exception as error:
             exc_type, exc_obj, exc_tb = sys.exc_info()
@@ -231,7 +231,6 @@ class GenericControllerClass:
             flag_data["flag_update_report"] = False
             if(len(sql_data["sql_for_insert_cluster_execute"]["member_sql"]) > 0):
                 flag_data["flag_update_report"] = True
-                print("Insert cluster ...")
 
                 print("Insert cluster member ...")
                 sql_member_insert_cluster = sql_data["sql_for_insert_cluster_execute"]["member_sql"]
@@ -304,7 +303,6 @@ class GenericControllerClass:
     def executeInsertNewCluster(self, connect_db_output, flag_data, sql_data, generic):
         try:
             if(len(sql_data["sql_for_insert_execute"]["report_sql"]) > 0):
-                print("Insert new cluster")
                 print("Insert new cluster report ...")
                 sql_report_insert = sql_data["sql_for_insert_execute"]["report_sql"]
                 if(len(sql_data["sql_for_insert_execute"]["report_values"]) > 0):
@@ -560,7 +558,9 @@ class GenericControllerClass:
                 """
             return sql_for_update
         except Exception as error:
-            print ("Oops! An exception has occured:", error)
-            print ("Exception TYPE:", type(error))
-            print("Function genSqlUpdateRepresentativeDate")
+            exc_type, exc_obj, exc_tb = sys.exc_info()
+            fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            print(error, exc_type, fname, exc_tb.tb_lineno)
+            generic.process_status = False
+            generic.log.text_long += "Error genSqlUpdateRepresentativeDate , " + str(error) + " " + str(exc_type) + " " + str(fname) + " " + str(exc_tb.tb_lineno) + " "
             return False
\ No newline at end of file
