@@ -9,7 +9,7 @@ class LogController:
         self.logger.setLevel(logging.DEBUG)
         self.path_log_app = path_log_app
     def genLog(self, message, level):
-        file_name = self.path_log_app + "_" + datetime.now().strftime("%Y_%m_%d") + ".log"
+        file_name = self.path_log_app + datetime.now().strftime("%Y_%m_%d") + ".log"
         fh = logging.FileHandler(file_name, encoding = "UTF-8")
         formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
         fh.setFormatter(formatter)
