@@ -1,6 +1,7 @@
 import os.path
 import json
-
+import js2py
+import TimeLineCluster.ConfigReader as ConfigReader
 def readFileJson(path):
     if(os.path.exists(path)):
         try:
@@ -20,6 +21,10 @@ def fileExists(path):
     else:
         return False
 
+def getEpWeek(date):
+    eval_res, tempfile = js2py.run_file(ConfigReader.ConfigPath.path_js + "getWOY.js")
+    ep = tempfile.getWeekOfYear(str(date))
+    return ep
 
 def writeLastUpdateSurveyJson(filename , last_update):
     dictionary = {
