@@ -1,6 +1,6 @@
 import TimeLineCluster.GenericController as GenericController
 import TimeLineCluster.UtilsController as UtilsController
-import TimeLineCluster.DBConnector as DBConnector
+import TimeLineCluster.DBConnector as DBConnector 
 from datetime import datetime
 class TimeLineClusterClass:
     def __init__(self, data_for_time_line_cluster) :
@@ -51,6 +51,9 @@ class TimeLineClusterClass:
         
         self.last_process_fail = {}
 
+        self.first_update_source = []
+        self.last_update_source = []
+
     def setSource(self, source_data, source_detail_data):
         self.source_data = source_data
         self.source_detail_data = source_detail_data
@@ -85,8 +88,8 @@ class TimeLineClusterClass:
                     #     # self.generic.log.genLog(self.generic.log.text_long, "error")
                     #     return False    
 
-                    first_update_source = source_data.iloc[0] # store first update timestamp
-                    last_update_source = source_data.iloc[len(source_data)-1] # store max update timestamp
+                    self.first_update_source = source_data.iloc[0] # store first update timestamp
+                    self.last_update_source = source_data.iloc[len(source_data)-1] # store max update timestamp
 
                     # sort data by pk, start_date
                     for_drop = []
@@ -135,11 +138,11 @@ class TimeLineClusterClass:
                         self.generic.log.text_long += "Clustering start time : " + str(datetime.now().strftime("%Y-%m-%d %H:%M:%S:%f")[:-3]) + " "
                         data_cluster_representative = self.generic.getClusterRepresentative(self.connect_db_output, self.generic, source) # get cluster
                         if(self.generic.process_status == False):
-                            self.genLogErrorPk(for_drop_report, unique_source_data, first_update_source, last_update_source)
+                            self.genLogErrorPk(for_drop_report, unique_source_data, self.first_update_source, self.last_update_source)
                             return
                         data_explore_cluster = self.generic.exploreCluster(self.connect_db_output, source, unique_source_data, i, source_by_create_date, data_cluster_representative, self.flag_data, self.generic) # check cluster
                         if(self.generic.process_status == False):
-                            self.genLogErrorPk(for_drop_report, unique_source_data, first_update_source, last_update_source)
+                            self.genLogErrorPk(for_drop_report, unique_source_data, self.first_update_source, self.last_update_source)
                             return
                         self.generic.log.text_long += "Clustering end time : " + str(datetime.now().strftime("%Y-%m-%d %H:%M:%S:%f")[:-3]) + " "
                         
@@ -151,15 +154,15 @@ class TimeLineClusterClass:
                         
                         self.generic.handleProcessMember(self.connect_db_output, source, source_by_create_date, source_detail_by_create_date, source_data_no_detail, self.model_app, self.flag_data, self.sql_data, data_cluster_representative, data_explore_cluster, self.generic)
                         if(self.generic.process_status == False):
-                            self.genLogErrorPk(for_drop_report, unique_source_data, first_update_source, last_update_source)
+                            self.genLogErrorPk(for_drop_report, unique_source_data, self.first_update_source, self.last_update_source)
                             return
                         self.generic.handleProcessSummary(self.connect_db_output, source, source_by_create_date, source_detail_by_create_date, self.model_app, self.flag_data, self.sql_data, data_cluster_representative, self.generic)
                         if(self.generic.process_status == False):
-                            self.genLogErrorPk(for_drop_report, unique_source_data, first_update_source, last_update_source)
+                            self.genLogErrorPk(for_drop_report, unique_source_data, self.first_update_source, self.last_update_source)
                             return
                         self.generic.handleProcessReport(source, self.model_app, self.flag_data, self.sql_data, data_cluster_representative, self.generic)
                         if(self.generic.process_status == False):
-                            self.genLogErrorPk(for_drop_report, unique_source_data, first_update_source, last_update_source)
+                            self.genLogErrorPk(for_drop_report, unique_source_data, self.first_update_source, self.last_update_source)
                             return
                         # self.model_app["report"] = data_process_report[0] # data model report
                         # self.flag_data = data_process_report[1] # self.flag_data
@@ -175,7 +178,7 @@ class TimeLineClusterClass:
                             if(self.generic.data_app_config["log_info"] == 1):
                                 self.generic.log.genLog(self.generic.log.text_long, "info")
                     
-                    self.writeFileUpdate(last_update_source[self.generic.data_app_config["field_last_update_timestamp"]])
+                    self.writeFileUpdate()
                 
             self.connect_db_output.closeAllConnection("output")
         except Exception as error:
@@ -187,14 +190,14 @@ class TimeLineClusterClass:
             self.status = False
             self.connect_db_output.closeAllConnection("output")
 
-    def writeFileUpdate(self, last_update):
+    def writeFileUpdate(self):
         if("field_last_update_timestamp" in self.generic.data_app_config):
-            UtilsController.writeLastUpdateSurveyJson(self.store_for_time_line_cluster["last_update_path"] , last_update)
+            UtilsController.writeLastUpdateSurveyJson(self.store_for_time_line_cluster["last_update_path"] , self.last_update_source[self.generic.data_app_config["field_last_update_timestamp"]])
 
     def genLogErrorPk(self, for_drop_report, unique_source_data, first_update_source, last_update_source):
         self.generic.process_status = True
         if("field_last_update_timestamp" in self.generic.data_app_config):
-            self.writeFileUpdate(last_update_source[self.generic.data_app_config["field_last_update_timestamp"]])
+            self.writeFileUpdate()
             self.generic.log.text_long += " | [update_timestamp : " + last_update_source[self.generic.data_app_config["field_last_update_timestamp"]] + " "
             self.last_process_fail["start_date"] = first_update_source[self.generic.data_app_config["field_last_update_timestamp"]]
             self.last_process_fail["end_date"] = last_update_source[self.generic.data_app_config["field_last_update_timestamp"]]
@@ -213,5 +216,5 @@ class TimeLineClusterClass:
             self.last_process_fail[pk] = pk_list
             i += 1
 
-        # self.generic.log.text_long += "]"
-        # self.generic.log.genLog(self.generic.log.text_long, "error")
\ No newline at end of file
+        self.generic.log.text_long += "]"
+        self.generic.log.genLog(self.generic.log.text_long, "error")
\ No newline at end of file
